#undef PACKAGE
#undef VERSION

#undef HAVE_LIBSM
#undef ENABLE_NLS
#undef HAVE_CATGETS
#undef HAVE_GETTEXT
#undef HAVE_LC_MESSAGES
#undef HAVE_STPCPY


#undef GUPPI_MAJOR_VERSION
#undef GUPPI_MINOR_VERSION
#undef GUPPI_MICRO_VERSION

#undef HAVE_GUILE
#undef HAVE_HISTORY
#undef HAVE_READLINE
#undef WORKING_GUILE_READLINE
#undef READLINE_LIB
#undef HAVE_LIBSM
#undef HAVE_GUILE_GTK
#undef HAVE_GUILE_GNOME
#undef USING_BONOBO


